#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-plugin-api
version:              2.3.0.0
visibility:           public
id:                   hls-plugin-api-2.3.0.0-24Gaj5RjQ6EMd9nQnMDuH
key:                  hls-plugin-api-2.3.0.0-24Gaj5RjQ6EMd9nQnMDuH
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server API for plugin communication
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  344d1433c471c686398d91bfd68eb661
exposed:              True
exposed-modules:
    Ide.Logger Ide.Plugin.Config Ide.Plugin.ConfigUtils
    Ide.Plugin.Error Ide.Plugin.Properties Ide.Plugin.RangeMap
    Ide.Plugin.Resolve Ide.PluginUtils Ide.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-plugin-api
hs-libraries:         HShls-plugin-api-2.3.0.0-24Gaj5RjQ6EMd9nQnMDuH
depends:
    Diff-1.0-EyI2PwVDvqcHEZdhq20a3S
    aeson-2.2.2.0-C59vZnSjH3DEmVbOnYEZqj base-4.18.2.1
    co-log-core-0.3.2.6-C0JcN1wRLfF81giKIOzO0p containers-0.6.7
    data-default-0.7.1.3-v65wBq6p7UHdeTWfWwzRF
    dependent-map-0.4.0.1-2zJACcI0koyFP5NiKTmv1F
    dependent-sum-0.7.2.0-IcjknoC6D7DFwrTtYaRu9s
    dlist-1.0-1Hu4TU8l65oIz4v1ZjWgTZ
    extra-1.7.16-DutWM4qj2UOFoGYeyZgh2s filepath-1.4.300.1 ghc-9.6.6
    hashable-1.4.7.0-DeckboSXRoV2uaWXBDn9RA
    hls-graph-2.3.0.0-BKCw9wgtA1S1PhMBjmLsTw
    hw-fingertree-0.1.2.1-6nI5RjjLCvoq2kRaGS5O7
    lens-5.3.5-BDZkiRzgsgQ2kD9evujAJa
    lens-aeson-1.2.3-109DWcpOKe54ubSJm1bpGn
    lsp-2.2.0.0-2KTRmNoJPpl1560kysBcbn
    megaparsec-9.7.1-CJoBjZmJLrLBZvTza0sfq8 mtl-2.3.1
    opentelemetry-0.8.0-DqdGNyWpO25GgL0O14ZPjv
    optparse-applicative-0.18.1.0-JRbhqUMlTBkCWkkrIaelno
    prettyprinter-1.7.2-HvkUgaUIGC1QRxB5LZpIj
    regex-tdfa-1.3.2.5-9aVe6H9O9607zCidRganW5
    row-types-1.0.1.2-7S0vgI9avfg4bfoPAHvMsQ stm-2.5.1.0 text-2.0.2
    time-1.12.2 transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-JwtBWAs5WUC67yAeM1UF4A
    unordered-containers-0.2.21-LjCRrPGX8vKp2UxAfh6M2

haddock-interfaces:
    /usr/share/doc/haskell-hls-plugin-api/html/hls-plugin-api.haddock

haddock-html:         /usr/share/doc/haskell-hls-plugin-api/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

